@@ -23,8 +23,7 @@ class Visualiser:
             audio = AudioSegment.from_mp3(filename + '.mp3')
         except:
             audio = AudioSegment.from_mp3(filename)
-        else:
-            raise FileNotFoundError
+            
         audio.export(filename + ".wav", format="wav")
 
     def display(self, bar_heights):
